@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: configure Dist::Zilla like RUSSOZ
-our $VERSION = '0.024';    # VERSION
+our $VERSION = '0.025';    # VERSION
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -96,6 +96,19 @@ has github => (
     },
 );
 
+has github_issues => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub {
+        return 0 unless $_[0]->github;
+        ( defined $_[0]->payload->{github_issues}
+              and $_[0]->payload->{github_issues} == 0 )
+          ? 0
+          : 1;
+    },
+);
+
 has task_weaver => (
     is      => 'ro',
     isa     => 'Bool',
@@ -158,7 +171,13 @@ sub configure {
         ],
     );
 
-    $self->add_plugins('GithubMeta')  if $self->github;
+    $self->add_plugins(
+        [
+            'GithubMeta' => {
+                issues => $self->github_issues,
+            }
+        ]
+    ) if $self->github;
     $self->add_plugins('AutoPrereqs') if $self->auto_prereqs;
 
     if ( $self->task_weaver ) {
@@ -180,6 +199,8 @@ sub configure {
     $self->add_plugins('ReportPhase') if $self->report;
     $self->add_bundle('Git')          if $self->git;
 
+    $self->add_plugins('Git::Contributors');
+
     $self->add_plugins('ExtraTests');
 
     return;
@@ -202,7 +223,7 @@ Dist::Zilla::PluginBundle::Author::RUSSOZ - configure Dist::Zilla like RUSSOZ
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -261,7 +282,7 @@ Dist::Zilla::PluginBundle::Author::RUSSOZ - configure Dist::Zilla like RUSSOZ
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 TASK CONTENTS
 
